.. _api.module_funcs:

======================
Module functions
======================


Aggregation functions
======================
.. currentmodule:: staircase

.. autosummary::
   :toctree: api/

   aggregate
   mean
   median
   min
   max



Miscellaneous functions
=========================
.. currentmodule:: staircase

.. autosummary::
   :toctree: api/

   sample
   hist_from_ecdf
   cov
   corr
   make_test_data